@@ -1,5 +1,5 @@
 /*
- * $Id: ktreeview.cpp 465369 2005-09-29 14:33:08Z mueller $
+ * $Id: ktreeview.cpp 476543 2005-11-01 13:53:50Z mlaurent $
  *
  * KTreeView implementation
  *
@@ -25,10 +25,16 @@
 #include <ktreeview.h>
 #include "ktreeview.moc"
 #include <qapplication.h>			/* used for QApplication::closingDown() */
-#include <qkeycode.h>			/* used for keyboard interface */
+#include <qnamespace.h>			/* used for keyboard interface */
 #include <qpainter.h>			/* used to paint items */
 #include <qscrollbar.h>
 #include <qstyle.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <QFocusEvent>
+#include <QKeyEvent>
+#include <Q3Frame>
+#include <QMouseEvent>
 #include <assert.h>
 
 /*
@@ -371,8 +377,9 @@ void KTreeViewItem::paintText(QPainter* p, int indent, int cellHeight,
     int textY = cellHeight - ((cellHeight - p->fontMetrics().ascent() -
 			       p->fontMetrics().leading()) / 2);
     if (highlighted) {
-	paintHighlight(p, indent, cg, owner->hasFocus(),
-                       (Qt::GUIStyle)owner->style().styleHint(QStyle::SH_GUIStyle)); // Qt3 doesn't make this easy ;)
+        Qt::GUIStyle sty; 
+	paintHighlight(p, indent, cg, owner->hasFocus(), sty
+                     /* FIXME  (Qt::GUIStyle)owner->style().styleHint(QStyle::SH_GUIStyle)*/ ); // Qt3 doesn't make this easy ;)
 	p->setPen(cg.base());
 	p->setBackgroundColor(cg.text());
     }
@@ -575,8 +582,8 @@ int KTreeViewItem::width(int indent, const QFontMetrics& fm) const
 // constructor
 KTreeView::KTreeView(QWidget *parent,
 		     const char *name,
-		     WFlags f) :
-	QGridView(parent, name, f),
+		     Qt::WFlags f) :
+	Q3GridView(parent, name, f),
 	clearing(false),
 	current(-1),
 	drawExpandButton(true),
@@ -598,7 +605,7 @@ KTreeView::KTreeView(QWidget *parent,
     //switch(style().guiStyle()) {
     //case WindowsStyle:
     //case MotifStyle:
-	setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
+	setFrameStyle(Q3Frame::WinPanel | Q3Frame::Sunken);
 	setBackgroundColor(colorGroup().base());
 	//break;
     /*default:
@@ -723,7 +730,7 @@ void KTreeView::clear()
 
 	bool autoU = autoUpdate();
 	setAutoUpdate(FALSE);
-	QPtrStack<KTreeViewItem> stack;
+	QStack<KTreeViewItem *> stack;
 	stack.push(treeRoot);
 	while(!stack.isEmpty()) {
 		KTreeViewItem *item = stack.pop();
@@ -960,7 +967,7 @@ KTreeViewItem* KTreeView::itemAt(const KPath& path)
 
     // need a copy of the path because recursiveFind will destroy it
     KPath pathCopy;
-    pathCopy.setAutoDelete(false);
+    //pathCopy.setAutoDelete(false);
     pathCopy = path;
 
     return recursiveFind(pathCopy);
@@ -1406,7 +1413,7 @@ void KTreeView::forEveryItem(KForEveryM func,
 			   void *user)
 {
   KTreeViewItem *item = treeRoot->getChild();
-  QPtrStack<KTreeViewItem> stack;
+  QStack<KTreeViewItem *> stack;
   while(item) {
     stack.push(item);
     while(!stack.isEmpty()) {
@@ -1432,7 +1439,7 @@ void KTreeView::forEveryItem(KForEveryM func,
 void KTreeView::forEveryVisibleItem(KForEveryM func,
 				       void *user)
 {
-  QPtrStack<KTreeViewItem> stack;
+  QStack<KTreeViewItem *> stack;
   KTreeViewItem *item = treeRoot->getChild();
   do {
     while(item) {
@@ -1565,7 +1572,7 @@ void KTreeView::keyPressEvent(QKeyEvent *e)
     setCurrentItem(rowAt(contentsY()));
   int pageSize, delta;
   switch(e->key()) {
-    case Key_Up:
+    case Qt::Key_Up:
 
       // make previous item current, scroll up if necessary
 
@@ -1574,7 +1581,7 @@ void KTreeView::keyPressEvent(QKeyEvent *e)
         ensureCellVisible(currentItem(), 0);
       }
       break;
-    case Key_Down:
+    case Qt::Key_Down:
 
       // make next item current, scroll down if necessary
 
@@ -1583,38 +1590,38 @@ void KTreeView::keyPressEvent(QKeyEvent *e)
         ensureCellVisible(currentItem(), 0);
       }
       break;
-    case Key_Next:
+    case Qt::Key_PageDown:
 
       // move highlight one page down and scroll down
 
-      delta = QMAX(1, visibleHeight() / cellHeight());
-      setCurrentItem(QMIN(currentItem() + delta, numRows() - 1));
+      delta = qMax(1, visibleHeight() / cellHeight());
+      setCurrentItem(qMin(currentItem() + delta, numRows() - 1));
       ensureCellVisible(currentItem(), 0);
       break;
-    case Key_Prior:
+    case Qt::Key_PageUp:
 
       // move highlight one page up and scroll up
 
-      delta = QMAX(1, visibleHeight() / cellHeight());
-      setCurrentItem(QMAX(currentItem() - delta, 0));
+      delta = qMax(1, visibleHeight() / cellHeight());
+      setCurrentItem(qMax(currentItem() - delta, 0));
       ensureCellVisible(currentItem(), 0);
       break;
-    case Key_Plus:
+    case Qt::Key_Plus:
 
       // if current item has subtree and is collapsed, expand it
 
       if(currentItem() >= 0)
 	expandItem(currentItem());
       break;
-    case Key_Minus:
+    case Qt::Key_Minus:
 
       // if current item has subtree and is expanded, collapse it
 
       if(currentItem() >= 0)
 	collapseItem(currentItem());
       break;
-    case Key_Return:
-    case Key_Enter:
+    case Qt::Key_Return:
+    case Qt::Key_Enter:
 
       // select the current item
 
@@ -1701,7 +1708,7 @@ void KTreeView::mousePressEvent(QMouseEvent *e)
 {
     // first: check which button was pressed
 
-    if (e->button() == MidButton)
+    if (e->button() == Qt::MidButton)
     {
 	// RB: the MMB is hardcoded to the "rubberband" scroll mode
 	if (!rubberband_mode) {
@@ -1709,7 +1716,7 @@ void KTreeView::mousePressEvent(QMouseEvent *e)
 	}
 	return;
     }
-    else if ( ( rubberband_mode ) && ( e->button() != RightButton ) )
+    else if ( ( rubberband_mode ) && ( e->button() != Qt::RightButton ) )
     {
 	// another button was pressed while rubberbanding, stop the move.
 	// RB: if we allow other buttons while rubberbanding the tree can expand
@@ -1751,7 +1758,7 @@ void KTreeView::mousePressEvent(QMouseEvent *e)
     // hit item (to show info on the file/dir label clicked)
     else if (item->boundingRect(indentation(item)).contains(cellCoord)) {
       setCurrentItem(itemClicked);   // highlight item
-        if ( e->button() == RightButton ) {
+        if ( e->button() == Qt::RightButton ) {
             emit popupMenu( itemClicked, mapToGlobal( QPoint( e->pos().x(), e->pos().y() ) ) );
         }
     }
@@ -1761,7 +1768,7 @@ void KTreeView::mousePressEvent(QMouseEvent *e)
 void KTreeView::mouseReleaseEvent(QMouseEvent *e)
 {
   /* if it's the MMB end rubberbanding */
-  if (rubberband_mode && e->button()==MidButton)
+  if (rubberband_mode && e->button()==Qt::MidButton)
 	{
 	  end_rubberband();
 	}
@@ -1772,7 +1779,7 @@ void KTreeView::draw_rubberband()
 {
 #if 0
     /*
-     * RB: I'm using a white pen because of the XorROP mode. I would prefer
+     * RB: I'm using a Qt::white pen because of the XorROP mode. I would prefer
      * to draw the rectangle in red but I don't now how to get a pen which
      * draws red in XorROP mode (this depends on the background). In fact
      * the color should be configurable.
@@ -1780,7 +1787,7 @@ void KTreeView::draw_rubberband()
 
   if (!rubberband_mode) return;
   QPainter paint(this);
-  paint.setPen(white);
+  paint.setPen(Qt::white);
   paint.setRasterOp(XorROP);
   paint.drawRect(xOffset()*viewWidth()/totalWidth(),
                  yOffset()*viewHeight()/totalHeight(),
@@ -1858,7 +1865,7 @@ void KTreeView::paintCell(QPainter* p, int row, int)
     if (item == 0)
 	return;
 
-    p->setClipRect(cellRect(), QPainter::CoordPainter );
+    p->setClipRect(cellRect() /* FIXME, QPainter::CoordPainter*/ );
     QColorGroup cg = colorGroup();
     int indent = indentation(item);
     item->paint(p, indent, cg,
