@@ -24,22 +24,22 @@
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
 
+#ifndef KPLVIEW_H
+#define KPLVIEW_H
 
-#ifndef KPLVITEM_H
-#define KPLVITEM_H
-
-#include "../config.h"
 // Standard Headers
 
 // Qt Headers
-#include <qframe.h>
-#include <qpushbutton.h>
-#include <qptrlist.h>
-#include <qstring.h>
-#include <qlayout.h>
+#include <QtGui/QPushButton>
+#include <Qt3Support/Q3PtrList>
+
+#include <QtGui/QLayout>
+//Added by qt3to4:
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPixmap>
 
 // KDE headers
-#include "klistview.h"
+#include "k3listview.h"
 
 // ksetup headers
 #include "packageInfo.h"
@@ -47,7 +47,7 @@
 class packageDisplayWidget;
 
 ////////////////////////////////////////////////////////////////////////
-class KpTreeList: public KListView
+class KpTreeList: public K3ListView
 {
   Q_OBJECT
 
@@ -57,14 +57,14 @@ public:
   void contentsMousePressEvent ( QMouseEvent * e );
 
   bool inMark(int x);
-
+  
   KpTreeListItem *firstChild();
   KpTreeListItem *currentItem();
   void clear();
 
   KpTreeListItem *markPkg;
 
-  QPtrList<KpTreeListItem> stack;
+  Q3PtrList<KpTreeListItem> stack;
   // Stack of jumped to packages
 
   void sweep(bool init);
@@ -72,7 +72,7 @@ public:
   void expand();
   // sweep tree expanding everything
 
-  void findMarked(KpTreeListItem *item, QPtrList<KpTreeListItem> &selList);
+  void findMarked(KpTreeListItem *item, Q3PtrList<KpTreeListItem> &selList);
   // generate list of marked tree items
   void clearMarked(KpTreeListItem *item);
   // unmark marked tree items
@@ -95,7 +95,7 @@ public:
   void countMarked(KpTreeListItem *, int &cntInstall, int &cntUnInstall);
   // Count marked packages that can be installed/uninstalled
 
-  void packageHighlighted(QListViewItem *item, packageDisplayWidget *packageDisplay);
+  void packageHighlighted(Q3ListViewItem *item, packageDisplayWidget *packageDisplay);
   // A package has been highlighted in the list tree
 
   KpTreeListItem *search(const QString &str, const QString &head,
@@ -108,12 +108,8 @@ public:
   void stackRemove(KpTreeListItem *pack);
   // Remove entry from package stack
 
-  void readTreeType();
-  void writeTreeType();
-  // config: Tree display type
-
-  void writeTreeConfig();
-  void readTreeConfig();
+  void writeTreePos();
+  void readTreePos();
   // save and restore column positions
 
  int treeType;
@@ -145,34 +141,33 @@ private:
 
   // flag skipping in searchChild
 
-
+  KpTreeListItem *topLevelItem(int i);
+ 
 signals:
   void updateMarked();
   void cleared();
 };
 
 ////////////////////////////////////////////////////////////////////////
-class KpTreeListItem : public QListViewItem
+class KpTreeListItem : public Q3ListViewItem
 {
-public:
-  KpTreeListItem( QListViewItem *parent, packageInfo* pinfo,
-	    const QPixmap& thePixmap,
-	    QString label1 = 0, QString label2  = 0,
-	    QString label3  = 0, QString label4  = 0,
-	    QString label5  = 0, QString label6  = 0,
-	    QString label7  = 0, QString label8 = 0);
+  public:
+   KpTreeListItem( Q3ListViewItem *parent, packageInfo* pinfo,
+            const QPixmap& thePixmap,
+            QString label1 = 0, QString label2  = 0,
+            QString label3  = 0, QString label4  = 0,
+            QString label5  = 0, QString label6  = 0,
+            QString label7  = 0, QString label8 = 0);
 
+  KpTreeListItem( K3ListView *parent, packageInfo* pinfo,
+            const QPixmap& thePixmap,
+            QString label1 = 0, QString label2  = 0,
+            QString label3  = 0, QString label4  = 0,
+            QString label5  = 0, QString label6  = 0,
+            QString label7  = 0, QString label8 = 0);
 
-  KpTreeListItem( KListView *parent, packageInfo* pinfo,
-	    const QPixmap& thePixmap,
-	    QString label1 = 0, QString label2  = 0,
-	    QString label3  = 0, QString label4  = 0,
-	    QString label5  = 0, QString label6  = 0,
-	    QString label7  = 0, QString label8 = 0);
-
-
-  KpTreeListItem *firstChild();
-  KpTreeListItem *nextSibling();
+   KpTreeListItem *firstChild();
+   KpTreeListItem *nextSibling();
 
   void toggleMark();
   void setMark(bool mark);
@@ -181,11 +176,10 @@ public:
   void hide();
   void show();
 
-  virtual int compare( QListViewItem *i, int col, bool ascending ) const;
+  virtual int compare( Q3ListViewItem *i, int col, bool ascending ) const;
 
   packageInfo *info;
   bool marked;
 };
 
-
-#endif
+#endif // KPLVIEW_H
