@@ -425,7 +425,7 @@ void KSVTopLevel::initStatusBar()
   connect (mAuth, SIGNAL (authChanged(bool)), this, SLOT(writingEnabled(bool)));
 
   authIconBox->setWhatsThis( i18n ("<p>If the lock is closed <img src=\"user|ksysv_locked\"/>, "\
-                                      "you don't have the right " \
+                                      "you do not have the right " \
                                       "<strong>permissions</strong> to edit the init configuration.</p>" \
                                       "<p>Either restart %1 as root (or another more privileged user), " \
                                       "or ask your sysadmin to install %2 <em>suid</em> or " \
